import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import _defineProperty from "@babel/runtime/helpers/defineProperty";

/**
 * @license
 * Copyright © 2017-2019 Moov Corporation.  All rights reserved.
 */
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import analytics, { configureAnalytics } from './analytics';
import isLighthouse from './utils/isLighthouse';
import { Provider } from 'mobx-react';
/**
 * Use this component to register your analytics targets.
 * 
 * import AnalyticsProvider from 'react-storefront/AnalyticsProvider'
 * import GoogleAnalyticsTarget from 'react-storefront-extensions/GoogleAnalyticsTarget'
 * 
 * Example:
 * 
 * ```
 *  <AnalyticsProvider
 *    targets={isLighthouse => (isLighthouse ? [] : [
 *      new GoogleAnalyticsTarget({
 *        trackingID: 'ABC123'
 *      })
 *    ])}
 *  >
 *    <App/>
 *  </AnalyticsProvider>
 * ```
 * 
 * Components that are decendents of AnalyticsProvider can use `@inject('analytics')` to get access to
 * an object which can be used to broadcase analytics events to targets:
 * 
 * ```
 *  import React, { Component } from 'react'
 *  import Button from '@material-ui/core/Button'
 *  import { inject } from 'mobx-react'
 * 
 *  @inject('analytics')
 *  class MyComponent extends Component {
 * 
 *    render() {
 *      return (
 *        <Button onClick={this.fireAnalyticsEvent}>Click Me</Button>
 *      )
 *    }
 * 
 *    // This will call the someEvent() method on all configured analytics targets.
 *    fireAnalyticsEvent = () => {
 *      const eventData = { foo: 'bar' }
 *      this.props.analytics.fire('someEvent', eventData) // analytics prop is provided by the @inject('analytics') decorator.
 *    }
 * 
 *  }
 * ```
 */

var AnalyticsProvider =
/*#__PURE__*/
function (_Component) {
  _inherits(AnalyticsProvider, _Component);

  function AnalyticsProvider() {
    _classCallCheck(this, AnalyticsProvider);

    return _possibleConstructorReturn(this, _getPrototypeOf(AnalyticsProvider).apply(this, arguments));
  }

  _createClass(AnalyticsProvider, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      if (this.props.targets) {
        configureAnalytics.apply(void 0, _toConsumableArray(this.props.targets(isLighthouse())));
      }
    }
  }, {
    key: "render",
    value: function render() {
      return React.createElement(Provider, {
        analytics: analytics
      }, this.props.children);
    }
  }]);

  return AnalyticsProvider;
}(Component);

_defineProperty(AnalyticsProvider, "propTypes", {
  /**
   * Function which should return desired analytics targets to configure
   * An argument is passed to the function which indicates if in Lighthouse
   */
  targets: PropTypes.func.isRequired
});

export { AnalyticsProvider as default };
//# sourceMappingURL=AnalyticsProvider.js.map